﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.IO.Ports;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using System.Timers;

namespace Testprogramm
{
	//=== Class: MainWindow =================================================================================
	///
	/// @brief  Beschreibt eine Klasse, die von der Klasse Window abgeleitet wird.  
	///         Beschreibt dein Nebenfenster der Anwendung.
	/// 
	/// @class  Klasse beinhaltet Interaktionslogik (Verhalten) für das Fenster SecondWindow.xaml
	/// 
	//=======================================================================================================
	public partial class SecondWindow : Window
	{
		// Neues Objekt der Klasse "SerialPort" intanzieren
		// Verwendung des überladenen Konstruktors zur Initialisierung des Objektes/ der Schnittstelle
		static SerialPort serialPort = new SerialPort("COM8",
													  9600,
													  Parity.Even,
													  8,
													  StopBits.One);

		//=== Konstruktor: SecondWindow =========================================================================
		///
		/// @brief  Konstruktor wird aufgerufen, wenn das Fenster "SecondWindow" instanziert wird 
		/// 
		/// @param  void
		/// 
		//=======================================================================================================
		public SecondWindow()
		{
			// Fenster initialisieren
			InitializeComponent();
			// Eventhalder für den Empfang eines Datenpakets auf das Objekt "serialPort" abbonieren
			serialPort.DataReceived += new SerialDataReceivedEventHandler(SerialPortDataReceived);
			// Serielle Schnittstelle öffnen, falls diese geschlossen ist
			if (!serialPort.IsOpen)
			{
				serialPort.Open();
			}
		}

		//=== Eventhandler: ButtonRefreshClick ==================================================================
		///
		/// @brief  Eventhandler wird aufgerufen wenn der Button "buttonRefresh" gedrückt wird
		/// 
		/// @param  object eventSender, RoutedEventArgs eventData
		/// 
		/// @return
		//=======================================================================================================
		private void ButtonRefreshClick(object eventSender,
										RoutedEventArgs eventData)
		{
			// Hintergrund weiß färben
			textBox1.Background = Brushes.White;
			// Text löschen
			textBox1.Text = "";
		}

		//=== Eventhandler: ButtonBeendenClick ==================================================================
		///
		/// @brief  Eventhandler wird aufgerufen wenn der Button "buttonClose" gedrückt wird
		/// 
		/// @param  object eventSender, RoutedEventArgs eventData
		/// 
		/// @return
		//=======================================================================================================
		private void ButtonBeendenClick(object eventSender,
										RoutedEventArgs eventData)
		{
			// Serielle Schnittstelle schließen, falls diese offen ist
			if (serialPort.IsOpen)
			{
				serialPort.Close();
			}
			// Fenster schliesen
			this.Close();
		}

		//=== Eventhandler: SerialPortDataReceived ==============================================================
		///
		/// @brief  Eventhandler wird aufgerufen wenn über die serielle Schnittstelle ein Datenpakeit (5..9 Bits)
		///			empfangen wurde
		/// 
		/// @param  object eventSender, SerialDataReceivedEventArgs e
		/// 
		/// @return
		//=======================================================================================================
		private void SerialPortDataReceived(object sender,
											SerialDataReceivedEventArgs e)
		{
			// Empfangene Daten aufbereiten und in diesem Fenster ausgeben
			Dispatcher.Invoke(new Action(() =>
			{
				// Wenn 1 Byte empfangen wurde, wird etwas im Fenster geändert
				if (serialPort.BytesToRead == 1)
				{
					// Hintergrund grün färben
					textBox1.Background = Brushes.Lime;
					// Text ausgeben
					textBox1.Text = "Daten Empfangen";
					// Empfangspuffer löschen
					serialPort.DiscardInBuffer();
				}
			}
			));
		}


	}
}
